==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d0/d6d/structOrderList.js <==
var structOrderList =
[
    [ "OrderList", "d0/d6d/structOrderList.html#a7f554db9c6a0e57be6a83115f1bd1dd0", null ],
    [ "OrderList", "d0/d6d/structOrderList.html#a21ce72c6d22923c9c20bd0460d5e4d17", null ],
    [ "~OrderList", "d0/d6d/structOrderList.html#a5640cc74278c036f64300afab94db0bc", null ],
    [ "AddVehicle", "d0/d6d/structOrderList.html#a78c279f70457801954a648e1db42c32c", null ],
    [ "DebugCheckSanity", "d0/d6d/structOrderList.html#a9be7d34d309d8cc9554af040a2c9dfcc", null ],
    [ "DeleteOrderAt", "d0/d6d/structOrderList.html#a151efa5a47a44ee68e2f780546d34b9f", null ],
    [ "FreeChain", "d0/d6d/structOrderList.html#ac8599685dd73bbd08d1f75fac8f522f1", null ],
    [ "GetBestLoadableNext", "d0/d6d/structOrderList.html#a24bd4a31a3a8057005a5543bbcb01170", null ],
    [ "GetFirstOrder", "d0/d6d/structOrderList.html#ace067134c88ff45d10b17acbd3231d26", null ],
    [ "GetFirstSharedVehicle", "d0/d6d/structOrderList.html#ad1a8d653fd6333e3a7b5fdf21daaada0", null ],
    [ "GetLastOrder", "d0/d6d/structOrderList.html#a602b42d343743c1ffa7f24830fead052", null ],
    [ "GetNext", "d0/d6d/structOrderList.html#aba0f8c8b008180c10ae220dfca670ae5", null ],
    [ "GetNextDecisionNode", "d0/d6d/structOrderList.html#a54060a4b04e35841e6caea869b5177e6", null ],
    [ "GetNextStoppingStation", "d0/d6d/structOrderList.html#adcafe7e104d1beffc00d73f1512d1bd5", null ],
    [ "GetNumManualOrders", "d0/d6d/structOrderList.html#accf944676a9078355540102f6674419e", null ],
    [ "GetNumOrders", "d0/d6d/structOrderList.html#ac5a3f70980452916e9c8252fea3d0285", null ],
    [ "GetNumVehicles", "d0/d6d/structOrderList.html#a4e688e50e5105f0091683161bbc10a66", null ],
    [ "GetOrderAt", "d0/d6d/structOrderList.html#a7cfd5846f776d21d9b29c8d7abc71225", null ],
    [ "GetPositionInSharedOrderList", "d0/d6d/structOrderList.html#af7ac7d77d2b81442296033bd699c6ae0", null ],
    [ "GetTimetableDurationIncomplete", "d0/d6d/structOrderList.html#ae2d18dc63851686ce88e0960df801d24", null ],
    [ "GetTimetableTotalDuration", "d0/d6d/structOrderList.html#a48b7d569d8809ab5cf1ae96b3419dd74", null ],
    [ "GetTotalDuration", "d0/d6d/structOrderList.html#a96d57a8000ee95493f85fae646a477cb", null ],
    [ "Initialize", "d0/d6d/structOrderList.html#a5b7d709d98f5d51e6788fbf8fa7befa8", null ],
    [ "InsertOrderAt", "d0/d6d/structOrderList.html#a77aff5c73b466017ceaf237bf4902895", null ],
    [ "IsCompleteTimetable", "d0/d6d/structOrderList.html#a3de23d9b6264756dc9e048ce9b1c61a0", null ],
    [ "IsShared", "d0/d6d/structOrderList.html#aeca4ada10cb8020e7a85146f72fc324a", null ],
    [ "IsVehicleInSharedOrdersList", "d0/d6d/structOrderList.html#a4213361c6aef144dface79ae4b0080d2", null ],
    [ "MoveOrder", "d0/d6d/structOrderList.html#a8dcfd6b40746c876d3ebcf28dd2eb3f9", null ],
    [ "RemoveVehicle", "d0/d6d/structOrderList.html#a6494ad4cd53394c3e95d1fbba3f88bd1", null ],
    [ "UpdateTimetableDuration", "d0/d6d/structOrderList.html#a5c814c53fe7487502442a52c40ad7c22", null ],
    [ "UpdateTotalDuration", "d0/d6d/structOrderList.html#a5063bad2418f3c8229c1612006616ea9", null ],
    [ "AfterLoadVehicles", "d0/d6d/structOrderList.html#ad79cdc104c56cac598ae2b9bb32d7e88", null ],
    [ "GetOrderListDescription", "d0/d6d/structOrderList.html#a313afcc6a46d93099e36d5e688db83f7", null ],
    [ "first", "d0/d6d/structOrderList.html#a9068b1ed275f5e08448f3c822489c9a1", null ],
    [ "first_shared", "d0/d6d/structOrderList.html#a9dfba31a1fefadb424a6d3328697ee83", null ],
    [ "num_manual_orders", "d0/d6d/structOrderList.html#aad0bced95f2c6912dc38d0de00f22155", null ],
    [ "num_orders", "d0/d6d/structOrderList.html#a6f79c1a2f55f9477ee1bca60f749dcc8", null ],
    [ "num_vehicles", "d0/d6d/structOrderList.html#a698cd6abf1df29215e7c0075d886a35b", null ],
    [ "timetable_duration", "d0/d6d/structOrderList.html#a0c6f9b96b41c3b84e006b59ee48b17df", null ],
    [ "total_duration", "d0/d6d/structOrderList.html#af2f13e93c84dfb891cacb0bb64710065", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d0/d6d/structOrderList.js <==
var structOrderList =
[
    [ "OrderList", "d0/d6d/structOrderList.html#a7f554db9c6a0e57be6a83115f1bd1dd0", null ],
    [ "OrderList", "d0/d6d/structOrderList.html#a21ce72c6d22923c9c20bd0460d5e4d17", null ],
    [ "~OrderList", "d0/d6d/structOrderList.html#a5640cc74278c036f64300afab94db0bc", null ],
    [ "AddVehicle", "d0/d6d/structOrderList.html#a78c279f70457801954a648e1db42c32c", null ],
    [ "DebugCheckSanity", "d0/d6d/structOrderList.html#a9be7d34d309d8cc9554af040a2c9dfcc", null ],
    [ "DeleteOrderAt", "d0/d6d/structOrderList.html#a151efa5a47a44ee68e2f780546d34b9f", null ],
    [ "FreeChain", "d0/d6d/structOrderList.html#ac8599685dd73bbd08d1f75fac8f522f1", null ],
    [ "GetBestLoadableNext", "d0/d6d/structOrderList.html#a24bd4a31a3a8057005a5543bbcb01170", null ],
    [ "GetFirstOrder", "d0/d6d/structOrderList.html#ace067134c88ff45d10b17acbd3231d26", null ],
    [ "GetFirstSharedVehicle", "d0/d6d/structOrderList.html#ad1a8d653fd6333e3a7b5fdf21daaada0", null ],
    [ "GetLastOrder", "d0/d6d/structOrderList.html#a602b42d343743c1ffa7f24830fead052", null ],
    [ "GetNext", "d0/d6d/structOrderList.html#aba0f8c8b008180c10ae220dfca670ae5", null ],
    [ "GetNextDecisionNode", "d0/d6d/structOrderList.html#a54060a4b04e35841e6caea869b5177e6", null ],
    [ "GetNextStoppingStation", "d0/d6d/structOrderList.html#a24002618d14ce9081e68d1d650c4592e", null ],
    [ "GetNumManualOrders", "d0/d6d/structOrderList.html#accf944676a9078355540102f6674419e", null ],
    [ "GetNumOrders", "d0/d6d/structOrderList.html#ac5a3f70980452916e9c8252fea3d0285", null ],
    [ "GetNumVehicles", "d0/d6d/structOrderList.html#a4e688e50e5105f0091683161bbc10a66", null ],
    [ "GetOrderAt", "d0/d6d/structOrderList.html#a7cfd5846f776d21d9b29c8d7abc71225", null ],
    [ "GetPositionInSharedOrderList", "d0/d6d/structOrderList.html#af7ac7d77d2b81442296033bd699c6ae0", null ],
    [ "GetTimetableDurationIncomplete", "d0/d6d/structOrderList.html#ae2d18dc63851686ce88e0960df801d24", null ],
    [ "GetTimetableTotalDuration", "d0/d6d/structOrderList.html#a48b7d569d8809ab5cf1ae96b3419dd74", null ],
    [ "GetTotalDuration", "d0/d6d/structOrderList.html#a96d57a8000ee95493f85fae646a477cb", null ],
    [ "Initialize", "d0/d6d/structOrderList.html#a5b7d709d98f5d51e6788fbf8fa7befa8", null ],
    [ "InsertOrderAt", "d0/d6d/structOrderList.html#a77aff5c73b466017ceaf237bf4902895", null ],
    [ "IsCompleteTimetable", "d0/d6d/structOrderList.html#a3de23d9b6264756dc9e048ce9b1c61a0", null ],
    [ "IsShared", "d0/d6d/structOrderList.html#aeca4ada10cb8020e7a85146f72fc324a", null ],
    [ "IsVehicleInSharedOrdersList", "d0/d6d/structOrderList.html#a4213361c6aef144dface79ae4b0080d2", null ],
    [ "MoveOrder", "d0/d6d/structOrderList.html#a8dcfd6b40746c876d3ebcf28dd2eb3f9", null ],
    [ "RecalculateTimetableDuration", "d0/d6d/structOrderList.html#ac71e56dd1e24c3c8266b679e7ba28d8b", null ],
    [ "RemoveVehicle", "d0/d6d/structOrderList.html#a6494ad4cd53394c3e95d1fbba3f88bd1", null ],
    [ "UpdateTimetableDuration", "d0/d6d/structOrderList.html#a5c814c53fe7487502442a52c40ad7c22", null ],
    [ "UpdateTotalDuration", "d0/d6d/structOrderList.html#a5063bad2418f3c8229c1612006616ea9", null ],
    [ "AfterLoadVehicles", "d0/d6d/structOrderList.html#ad79cdc104c56cac598ae2b9bb32d7e88", null ],
    [ "GetOrderListDescription", "d0/d6d/structOrderList.html#a313afcc6a46d93099e36d5e688db83f7", null ],
    [ "first", "d0/d6d/structOrderList.html#a9068b1ed275f5e08448f3c822489c9a1", null ],
    [ "first_shared", "d0/d6d/structOrderList.html#a9dfba31a1fefadb424a6d3328697ee83", null ],
    [ "num_manual_orders", "d0/d6d/structOrderList.html#aad0bced95f2c6912dc38d0de00f22155", null ],
    [ "num_orders", "d0/d6d/structOrderList.html#a6f79c1a2f55f9477ee1bca60f749dcc8", null ],
    [ "num_vehicles", "d0/d6d/structOrderList.html#a698cd6abf1df29215e7c0075d886a35b", null ],
    [ "timetable_duration", "d0/d6d/structOrderList.html#a0c6f9b96b41c3b84e006b59ee48b17df", null ],
    [ "total_duration", "d0/d6d/structOrderList.html#af2f13e93c84dfb891cacb0bb64710065", null ]
];
